Worker_DAQ
===================
.. autoclass:: dvg_qdeviceio.Worker_DAQ
   :members: ,
   :member-order: bysource
   :show-inheritance:

Methods
--------------------

.. automethod:: dvg_qdeviceio.Worker_DAQ.pause
.. automethod:: dvg_qdeviceio.Worker_DAQ.unpause
.. automethod:: dvg_qdeviceio.Worker_DAQ.wake_up